<template>
  <div class="bbsl-common-page">
    <div class="bbsl-table-search">
      <el-form v-model="queryParam" label-width="auto">
        <el-row :gutter="10">
          <el-col :span="5">
            <el-form-item label="火灾时间">
              <el-date-picker v-model="querys[0].value" type="datetimerange" range-separator="至"
                start-placeholder="开始日期" end-placeholder="结束日期" value-format="yyyy-MM-dd hh:mm:ss">
              </el-date-picker>
            </el-form-item>
          </el-col>
          <el-col :span="5">
            <el-form-item label="火灾地点">
              <el-input v-model="querys[1].value" clearable placeholder="请输入火灾地点" />
            </el-form-item>
          </el-col>
          <el-col :span="5">
            <el-form-item label="起火原因">
              <el-input v-model="querys[2].value" clearable placeholder="请输入起火原因" />
            </el-form-item>
          </el-col>
          <el-col :span="4">
            <el-button type="primary" icon="el-icon-search" @click="handleSearch">搜索</el-button>
            <el-button icon="el-icon-refresh" @click="handleReset">重置</el-button>
          </el-col>
        </el-row>
      </el-form>
    </div>
    <div ref="contentPanel" class="bbsl-table-content">
      <div ref="btnPanel" class="bbsl-btn-content">
        <el-button icon="el-icon-plus" type="primary" @click="handleAdd">新增</el-button>
        <el-popconfirm title="确定删除选中数据吗？" @confirm="handleDelete">
          <el-button slot="reference" :disabled="!multipleSelection.length" icon="el-icon-delete" type="danger"
            style="margin-left: 10px">删除</el-button>
        </el-popconfirm>
      </div>
      <el-table ref="multipleSelection" v-loading="loading" border size="mini" :data="tableData"
        :style="{ width: '100%' }" :max-height="tableMaxHeight" :cell-style="{ 'text-align': 'center' }"
        :header-cell-style="{ 'text-align': 'center' }" @row-dblclick="handleDbClick"
        @selection-change="handleSelectionChange">
        <el-table-column type="selection" width="55" />
        <el-table-column fixed type="index" width="55" label="序号" />
        <el-table-column prop="fireAddress" min-width="150" label="火灾地点" show-overflow-tooltip />
        <el-table-column prop="fireReason" label="起火原因" show-overflow-tooltip />
        <el-table-column prop="fireTime" width="155" label="火灾时间" show-overflow-tooltip />
        <el-table-column prop="ssNum" width="80" label="受伤人数" show-overflow-tooltip />
        <el-table-column prop="swNum" width="80" label="死亡人数" show-overflow-tooltip />
        <el-table-column prop="fireDesc" label="灾情描述" show-overflow-tooltip />
        <el-table-column prop="cdqk" label="警情出动情况" show-overflow-tooltip />
      </el-table>
      <el-pagination ref="paginationPanel" align="right" background class="bbsl-pagination"
        :current-page="queryParam.pageBean.page" :page-sizes="[20, 30, 40, 50]"
        :page-size="queryParam.pageBean.pageSize" layout="total, sizes, prev, pager, next, jumper" :total="total"
        @size-change="handleSizeChange" @current-change="handleCurrentChange" />
    </div>
    <FireDisasterRecordDialog ref="formModal" />
  </div>
</template>

<script>
import { TableMixin } from '@/mixins/tableMixin'
import dictUtils from '@/components/dict/DictSelectUtils.js'
import dictContracts from '@/components/dict/DictSelectUtils.js'

import FireDisasterRecord from '@/views/Manage/saftyDanger/api/FireDisasterRecord'
import FireDisasterRecordDialog from '@/views/Manage/saftyDanger/components/FireDisasterRecordDialog'

export default {
  name: 'nineLittlePlace',
  components: {
    FireDisasterRecordDialog
  },
  mixins: [TableMixin],
  data() {
    return {
      url: {
        delete: '/manager/cmgtSaftyDangerUnit/delete'
      },
      querys: [
        {
          group: 'main',
          operation: 'BETWEEN',
          parentGroup: '',
          property: 'fire_time_',
          relation: 'AND',
          value: ''
        },
        {
          group: 'main',
          operation: 'LIKE',
          parentGroup: '',
          property: 'fire_address_',
          relation: 'AND',
          value: ''
        },
        {
          group: 'main',
          operation: 'LIKE',
          parentGroup: '',
          property: 'fire_reason_',
          relation: 'AND',
          value: ''
        }
      ],
      StshowFormDias: false,
      types: [],
      sorter: [
        {
          direction: 'ASC',
          property: 'SN_'
        }
      ]
      // levels:[]
    }
  },
  created() {
    this.types = dictContracts.getDictItemsFromCache('cmgt_aqyhpcdwlb')
    this.fxjbList = dictUtils.getDictItemsFromCache('fxjb') //风险级别
    this.zddwflList = dictUtils.getDictItemsFromCache('zddwfl') //重点单位分类
    this.jxcslxList = dictUtils.getDictItemsFromCache('jxcslx') //九小场所类型
    this.jxcspqList = dictUtils.getDictItemsFromCache('jxcspq') //九小场所片区
    this.rlzlList = dictUtils.getDictItemsFromCache('rlzl') //燃料种类
    this.tysfList = dictUtils.getDictItemsFromCache('ty-sf') //是否三合一
    // this.levels = dictContracts.getDictItemsFromCache('cmgt_aqyhfxjb')
  },
  mounted() { },
  methods: {
    // 重置
    clearQuerys() {
      this.querys[0].value = ''
      this.querys[1].value = ''
      this.querys[2].value = ''
    },
    // 获取list
    loadData(page) {
      if (page) {
        this.queryParam.pageBean.page = page
      }
      this.loading = true
      this.tableData = []
      this.queryParam.querys = []
      this.queryParam.sorter = this.sorter
      if (this.querys[0].value) {
        this.queryParam.querys.push(this.querys[0])
      }
      if (this.querys[1].value) {
        this.queryParam.querys.push(this.querys[1])
      }
      if (this.querys[2].value) {
        this.queryParam.querys.push(this.querys[2])
      }
      FireDisasterRecord.cmgtSaftyFiredisasterQuery(this.queryParam, res => {
        this.total = res.total
        this.tableData = res.rows
        this.tableData.forEach(item => {
          this.jxcspqList.forEach(val => {
            if (item.smallPlaceArea == val.value) {
              item['smallPlaceAreaName'] = val.name
            }
          })
          item['emphasisTypeName'] = ''
          this.zddwflList.forEach(val => {
            // console.log(item.emphasisType)
            if (item.emphasisType) {
              item.emphasisType.split(',').forEach((e, ei) => {
                if (e == val.value) {
                  if (ei + 1 < item.emphasisType.split(',').length) {
                    item['emphasisTypeName'] += val.name + ','
                  } else {
                    item['emphasisTypeName'] += val.name
                  }
                }
              })
            }
          })
          this.fxjbList.forEach(val => {
            if (item.riskLevel == val.value) {
              item['riskLevelName'] = val.name
            }
          })
          this.rlzlList.forEach(val => {
            if (item.fuelType == val.value) {
              item['fuelTypeName'] = val.name
            }
          })
        })
        this.$set(this.tableData)
        this.loading = false
      })
    },
    // 修改
    handleUpdate(row) {
      console.log(row.id)
      this.$refs.formModal.Update(row)
    },
    closeStshowForm() {
      this.StshowFormDias = false
    },
    handleDelete() {
      //   console.log(this.multipleSelection)
      FireDisasterRecord.deleteCmgtSaftyFiredisaster(this.multipleSelection)
        .then(res => {
          if (res.state) {
            this.$notify({
              type: 'success',
              message: '删除成功',
              duration: 2000
            })
            this.queryParam.pageBean.page = 1
            this.loadData()
          }
        })
        .catch(res => {
          this.$notify({
            type: 'error',
            message: res.message,
            duration: 2000,
            offset: 80
          })
        })
    },
    // formartLevelName(row, column, cellValue, index){
    // 	var obj = this.levels.find(function(item) {
    // 		if (item.value === row.level) { //
    // 			return item
    // 		}
    // 	})
    // 	if (obj !== undefined) {
    // 		return obj.name;
    // 	} else {
    // 		return "";
    // 	}
    // },
    formartTyepName(row, column, cellValue, index) {
      var obj = this.types.find(function (item) {
        if (item.value === row.type) {
          //
          return item
        }
      })
      if (obj !== undefined) {
        return obj.name
      } else {
        return ''
      }
    }
  }
}
</script>
<style lang="scss" scoped>
.type-tag {
  margin: 0 2px;
}
</style>
